# Generated by Django 5.1.6 on 2025-02-25 15:43

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("hbdjinvoicing", "0001_initial"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="invoice",
            name="customer",
        ),
        migrations.DeleteModel(
            name="Customer",
        ),
    ]
