# Generated by Django 5.1.6 on 2025-02-26 16:42

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("hbdjinvoicing", "0003_alter_invoice_country_alter_organisation_country"),
    ]

    operations = [
        migrations.AlterField(
            model_name="invoice",
            name="street",
            field=models.TextField(),
        ),
        migrations.AlterField(
            model_name="organisation",
            name="street",
            field=models.TextField(),
        ),
    ]
